@@ -24,14 +24,20 @@
 Discover file multimedia information.
 """
 
-import gobject
-import gst
-import objectfactory
-
 from gettext import gettext as _
 import os.path
+import gobject
+import gst
 
-class Discoverer(gobject.GObject):
+from objectfactory import FileSourceFactory, PictureFileSourceFactory
+from signalinterface import Signallable
+
+# FIXME: We need to store more information regarding streams
+# i.e. remember the path took to get to a raw stream, and figure out
+# what encoded format it is
+# We will need that in order to create proper Stream objects.
+
+class Discoverer(object, Signallable):
     """
     Queues requests to discover information about given files.
     The discovery is done in a very fragmented way, so that it appears to be
@@ -44,34 +50,23 @@ class Discoverer(gobject.GObject):
 
     The "finished-analyzing" signal is emitted a file is finished being analyzed
 
-    The "starting" signal isemitted when the discoverer starts analyzing some
+    The "starting" signal is emitted when the discoverer starts analyzing some
     files.
 
     The "ready" signal is emitted when the discoverer has no more files to
     analyze.
     """
 
-    __gsignals__ = {
-        "new_sourcefilefactory" : (gobject.SIGNAL_RUN_LAST,
-                                   gobject.TYPE_NONE,
-                                   (gobject.TYPE_PYOBJECT, )),
-        "not_media_file" : (gobject.SIGNAL_RUN_LAST,
-                            gobject.TYPE_NONE,
-                            (gobject.TYPE_STRING, gobject.TYPE_STRING, gobject.TYPE_STRING)),
-        "finished_analyzing" : ( gobject.SIGNAL_RUN_LAST,
-                                 gobject.TYPE_NONE,
-                                 (gobject.TYPE_PYOBJECT, )),
-        "ready" : ( gobject.SIGNAL_RUN_LAST,
-                    gobject.TYPE_NONE,
-                    ( )),
-        "starting" : ( gobject.SIGNAL_RUN_LAST,
-                       gobject.TYPE_NONE,
-                       ( ))
+    __signals__ = {
+        "new_sourcefilefactory" : ["factory"],
+        "not_media_file" : ["a", "b", "c" ],
+        "finished_analyzing" : ["factory"],
+        "ready" : None,
+        "starting" : None,
         }
 
     def __init__(self, project):
         gst.log("new discoverer for project %s" % project)
-        gobject.GObject.__init__(self)
         self.project = project
         self.queue = []
         self.working = False
@@ -88,7 +83,8 @@ class Discoverer(gobject.GObject):
         self.error = None # reason for error
         self.extrainfo = None # extra information about the error
         self.fakesink = None
-        self.isimage = False # Used to know if the file is an image
+        self.__is_image = False # Used to know if the file is an image
+        self.bus = None
 
     def addFile(self, filename):
         """ queue a filename to be discovered """
@@ -153,14 +149,14 @@ class Discoverer(gobject.GObject):
             self.emit('not_media_file', self.current, self.error, self.extrainfo)
         elif self.currentfactory:
             self.currentfactory.addMediaTags(self.currentTags)
-            if self.isimage:
-                self.currentfactory.setThumbnail(gst.uri_get_location(self.current))
-            if not self.currentfactory.getDuration() and not self.isimage:
+            if self.__is_image:
+                self.currentfactory.thumbnail = gst.uri_get_location(self.current)
+            if not self.currentfactory.duration and not self.__is_image:
                 self.emit('not_media_file', self.current,
                           _("Could not establish the duration of the file."),
                           _("This clip seems to be in a format which cannot be accessed in a random fashion."))
             else:
-                self.emit('finished-analyzing', self.currentfactory)
+                self.emit('finished_analyzing', self.currentfactory)
         self.currentTags = []
         self.analyzing = False
         self.current = None
@@ -171,7 +167,7 @@ class Discoverer(gobject.GObject):
         self.nomorepads = False
         self.error = None
         self.extrainfo = None
-        self.isimage = False
+        self.__is_image = False
 
         # restart an analysis if there's more...
         if self.queue:
@@ -204,7 +200,8 @@ class Discoverer(gobject.GObject):
             gst.warning("This is not a media file : %s" % self.current)
             if not self.error:
                 self.error = _("Couldn't construct pipeline.")
-                self.extrainfo = _("GStreamer does not have an element to handle files coming from this type of file system.")
+                self.extrainfo = _("GStreamer does not have an element to "
+                                   "handle files coming from this type of file system.")
             gobject.idle_add(self._finishAnalysis)
             return False
         if os.getenv("USE_DECODEBIN2"):
@@ -215,7 +212,8 @@ class Discoverer(gobject.GObject):
         self.signalsid.append((dbin, dbin.connect("unknown-type", self._unknownTypeCb)))
         self.signalsid.append((dbin, dbin.connect("no-more-pads", self._noMorePadsCb)))
         tfind = dbin.get_by_name("typefind")
-        self.signalsid.append((tfind, tfind.connect("have-type", self._typefindHaveTypeCb)))
+        self.signalsid.append((tfind.get_pad("src"),
+                               tfind.get_pad("src").connect("notify::caps", self.__test)))
         self.pipeline.add(source, dbin)
         source.link(dbin)
         gst.info("analysis pipeline created")
@@ -242,9 +240,9 @@ class Discoverer(gobject.GObject):
         # return False so we don't get called again
         return False
 
-    def _typefindHaveTypeCb(self, typefind, perc, caps):
-        if caps.to_string().startswith("image/"):
-            self.isimage = True
+    def __test(self, apad, something):
+        if apad.get_caps().to_string().startswith("image/"):
+            self.__is_image = True
 
     def _busMessageCb(self, unused_bus, message):
         if self.thisdone:
@@ -259,7 +257,7 @@ class Discoverer(gobject.GObject):
                     # Let's get the information from all the pads
                     self._getPadsInfo()
                     # Only go to PLAYING if we have an video stream to thumbnail
-                    if self.currentfactory and self.currentfactory.is_video and not self.isimage:
+                    if self.currentfactory and self.currentfactory.is_video and not self.__is_image:
                         gst.log("pipeline has gone to PAUSED, now pushing to PLAYING")
                         if self.pipeline.set_state(gst.STATE_PLAYING) == gst.STATE_CHANGE_FAILURE:
                             if not self.error:
@@ -276,7 +274,7 @@ class Discoverer(gobject.GObject):
             self.thisdone = True
             filename = "/tmp/" + self.currentfactory.name.encode('base64').replace('\n','') + ".png"
             if os.path.isfile(filename):
-                self.currentfactory.setThumbnail(filename)
+                self.currentfactory.thumbnail = filename
             gobject.idle_add(self._finishAnalysis)
         elif message.type == gst.MESSAGE_ERROR:
             error, detail = message.parse_error()
@@ -322,51 +320,52 @@ class Discoverer(gobject.GObject):
 
             if caps and caps.is_fixed():
                 if not self.currentfactory:
-                    self.currentfactory = objectfactory.FileSourceFactory(self.current, self.project)
+                    self.currentfactory = self.__makefactory()
                     self.emit("new_sourcefilefactory", self.currentfactory)
+                # FIXME : we should just have to tell the factory that it contains a new stream
                 if caps.to_string().startswith("audio/x-raw") and not self.currentfactory.audio_info:
-                    self.currentfactory.setAudioInfo(caps)
+                    self.currentfactory.audio_info = caps
                 elif caps.to_string().startswith("video/x-raw") and not self.currentfactory.video_info:
-                    self.currentfactory.setVideoInfo(caps)
-            if not self.currentfactory.getDuration():
+                    self.currentfactory.video_info = caps
+            if not self.currentfactory.duration:
                 try:
                     length, format = pad.query_duration(gst.FORMAT_TIME)
                 except:
                     pad.warning("duration query failed")
                 else:
                     if format == gst.FORMAT_TIME:
-                        self.currentfactory.set_property("length", length)
+                        self.currentfactory.length = length
 
     def _vcapsNotifyCb(self, pad, unused_property):
         gst.info("pad:%s , caps:%s" % (pad, pad.get_caps().to_string()))
         if pad.get_caps().is_fixed() and (not self.currentfactory.video_info_stream or not self.currentfactory.video_info_stream.fixed):
-            self.currentfactory.setVideoInfo(pad.get_caps())
+            self.currentfactory.video_info = pad.get_caps()
 
     def _newVideoPadCb(self, element, pad):
         """ a new video pad was found """
         gst.debug("pad %s" % pad)
 
-        self.currentfactory.setVideo(True)
+        self.currentfactory.is_video = True
 
         if pad.get_caps().is_fixed():
-            self.currentfactory.setVideoInfo(pad.get_caps())
+            self.currentfactory.video_info = pad.get_caps()
 
-        q = gst.element_factory_make("queue")
-        q.props.max_size_bytes = 5 * 1024 * 1024
-        q.props.max_size_time = 5 * gst.SECOND
+        queue = gst.element_factory_make("queue")
+        queue.props.max_size_bytes = 5 * 1024 * 1024
+        queue.props.max_size_time = 5 * gst.SECOND
         csp = gst.element_factory_make("ffmpegcolorspace")
         pngenc = gst.element_factory_make("pngenc")
         pngsink = gst.element_factory_make("filesink")
         pngsink.set_property("location", "/tmp/" + self.currentfactory.name.encode('base64').replace('\n','') + ".png")
 
-        self.pipeline.add(q, csp, pngenc, pngsink)
-        gst.element_link_many(q, csp, pngenc, pngsink)
-        pad.link(q.get_pad("sink"))
+        self.pipeline.add(queue, csp, pngenc, pngsink)
+        gst.element_link_many(queue, csp, pngenc, pngsink)
+        pad.link(queue.get_pad("sink"))
 
         if not self.currentfactory.video_info:
             self.signalsid.append((pad, pad.connect("notify::caps", self._vcapsNotifyCb)))
 
-        for element in [q, csp, pngenc, pngsink]:
+        for element in [queue, csp, pngenc, pngsink]:
             element.set_state(gst.STATE_PAUSED)
 
         if self.currentfactory.is_audio:
@@ -377,7 +376,7 @@ class Discoverer(gobject.GObject):
         """ a new audio pad was found """
         gst.debug("pad %s" % pad)
 
-        self.currentfactory.setAudio(True)
+        self.currentfactory.is_audio = True
 
         # if we already saw another pad, remove no-more-pads hack
         if self.currentfactory.is_video:
@@ -386,18 +385,18 @@ class Discoverer(gobject.GObject):
 
         if pad.get_caps().is_fixed():
             gst.debug("fixed caps, setting info on factory")
-            self.currentfactory.setAudioInfo(pad.get_caps())
+            self.currentfactory.audio_info = pad.get_caps()
             # if we already have fixed caps, we don't need to take this stream.
         else:
             gst.debug("non-fixed caps, adding queue and fakesink")
             ##         if not self.currentfactory.is_video:
             # we need to add a fakesink
-            q = gst.element_factory_make("queue")
+            queue = gst.element_factory_make("queue")
             fakesink = gst.element_factory_make("fakesink")
-            self.pipeline.add(fakesink, q)
-            pad.link(q.get_pad("sink"))
-            q.link(fakesink)
-            q.set_state(gst.STATE_PAUSED)
+            self.pipeline.add(fakesink, queue)
+            pad.link(queue.get_pad("sink"))
+            queue.link(fakesink)
+            queue.set_state(gst.STATE_PAUSED)
             fakesink.set_state(gst.STATE_PAUSED)
 
     def _unknownTypeCb(self, unused_dbin, unused_pad, caps):
@@ -417,12 +416,12 @@ class Discoverer(gobject.GObject):
         gst.info("pad:%s caps:%s is_last:%s" % (pad, capsstr, is_last))
         if capsstr.startswith("video/x-raw"):
             if not self.currentfactory:
-                self.currentfactory = objectfactory.FileSourceFactory(self.current, self.project)
+                self.currentfactory = self.__makefactory()
                 self.emit("new_sourcefilefactory", self.currentfactory)
             self._newVideoPadCb(element, pad)
         elif capsstr.startswith("audio/x-raw"):
             if not self.currentfactory:
-                self.currentfactory = objectfactory.FileSourceFactory(self.current, self.project)
+                self.currentfactory = self.__makefactory()
                 self.emit("new_sourcefilefactory", self.currentfactory)
             self._newAudioPadCb(element, pad)
         else:
@@ -445,3 +444,11 @@ class Discoverer(gobject.GObject):
             self.pipeline.remove(self.fakesink)
             self.fakesink = None
         # normally state changes should end the discovery
+
+    def __makefactory(self):
+        if self.__is_image:
+            facttype = PictureFileSourceFactory
+        else:
+            facttype = FileSourceFactory
+        return facttype(filename=self.current,
+                        project=self.project)
